@@ -22,11 +22,13 @@ default_models = {
     "chat_completion": "gpt-3.5-turbo",
 }
 
+default_provider = "Aura"
+
 
 class GPT4FREE(Provider):
     def __init__(
         self,
-        provider: str = "Aura",
+        provider: str = default_provider,
         is_conversation: bool = True,
         auth: str = None,
         max_tokens: int = 600,
